@@ -2383,52 +2383,63 @@ gok_keyboard_follow_link (GokKey *key)
 	AccessibleHypertext *hypertext = NULL; 
 	AccessibleText *text = NULL;
 	AccessibleNode *node = key->pNodeAccessible;
+	AccessibleHyperlink *link = NULL;
 	gboolean is_editable = FALSE;
+	gboolean activated = FALSE;
 	if (node && node->paccessible) {
 		hypertext = Accessible_getHypertext (node->paccessible);
-		text = Accessible_getText (node->paccessible);
-		is_editable = Accessible_isEditableText (node->paccessible);
-		/* can't activate editable text this way, it will insert a space instead! */
-		if (hypertext && text && node->is_link && !is_editable) {
-			AccessibleHyperlink *link = AccessibleHypertext_getLink (hypertext, node->link);
-			Accessible *target;
-			AccessibleAction *action;
+		if (hypertext) {
+			Accessible *target = NULL;
+			AccessibleAction *action = NULL;
 			gboolean is_action = FALSE;
-			gboolean is_focussed = FALSE;
-			long int start, end;
-			AccessibleHyperlink_getIndexRange (link, &start, &end);
-			is_focussed = gok_keyboard_focus_object (node->paccessible);
-			if (!is_focussed) gok_log_x ("Could not focus object\n");
-			else {
-				AccessibleText_setCaretOffset (text, start);
-				SPI_generateKeyboardEvent ((long) XK_space, NULL, SPI_KEY_SYM);
+			if (node->link >= 0) {
+				link = AccessibleHypertext_getLink (hypertext, node->link);
+			}
+			if (link) {
+				target = AccessibleHyperlink_getObject (link, 0);
+				if (target) 
+					action = Accessible_getAction (target);
+			}
+			if (!action && link) { /* try the parent object? */
+				action = Accessible_getAction (link);
+				if (action) gok_log_x ("activating the link object.\n");
+				else gok_log_x ("link not actionable.\n");
+			}
+			if (action) {
+				activated = AccessibleAction_doAction (action, 0);
+				/* TODO: should check the action name first */
+				gok_log ("activating link\n");
+				AccessibleAction_unref (action);
 			}
-			target = AccessibleHyperlink_getObject (link, 0);
 			if (target) {
-				action = Accessible_getAction (target);
-				if (!action) { /* try the parent object? */
-					action = Accessible_getAction (link);
-					if (action) gok_log_x ("activating the link object.\n");
-				}
-				if (!action) { /* try the parent object? */
-					action = Accessible_getAction (node->paccessible);
-					if (action) gok_log_x ("activating the parent hypertext object!\n");
-				}
-				if (action) {
-					AccessibleAction_doAction (action, 0); /* HACK, should check the action first */
-					gok_log ("activating link\n");
-					AccessibleAction_unref (action);
-					is_action = TRUE;
-				}
 				Accessible_unref (target);
 			}
-			AccessibleText_unref (text);
-			AccessibleHyperlink_unref (link);
-			AccessibleHypertext_unref (text);
-			return is_action;
 		}
+		if (!activated) { /* fallback hack if text is focussable */
+			text = Accessible_getText (node->paccessible);
+			is_editable = Accessible_isEditableText (node->paccessible);
+			if (link && text && node->is_link && !is_editable) {
+				gboolean is_focussed = FALSE;
+				long int start, end;
+				AccessibleHyperlink_getIndexRange (link, &start, &end);
+				
+				/* can't activate editable text this way, it will insert a space instead! */
+				is_focussed = gok_keyboard_focus_object (node->paccessible);
+				if (!is_focussed) gok_log_x ("Could not focus object\n");
+				else {
+					AccessibleText_setCaretOffset (text, start);
+					SPI_generateKeyboardEvent ((long) XK_space, NULL, SPI_KEY_SYM);
+					activated = TRUE;
+				}
+				AccessibleText_unref (text);
+			}
+		}
+		if (link) 
+			AccessibleHyperlink_unref (link);
+		if (hypertext)
+			AccessibleHypertext_unref (hypertext);
 	}
-	return FALSE;
+	return activated;
 }
 
 
