@@ -74,8 +74,12 @@ typedef enum {
 	GOK_DIRECTION_SW,
 	GOK_DIRECTION_S,
 	GOK_DIRECTION_SE,
-	GOK_DIRECTION_FILL_EW
-} GokKeyboardDirection;
+	GOK_DIRECTION_FILL_EW,
+	GOK_RESIZE_NARROWER,
+	GOK_RESIZE_WIDER,
+	GOK_RESIZE_SHORTER,
+	GOK_RESIZE_TALLER
+} GokKeyboardDirection; /* TODO: since we're including resize we should rename this enum */
 
 
 typedef enum {
