@@ -299,6 +299,7 @@ gint gok_main_open(gint argc, gchar *argv[])
 		LIBGNOMEUI_MODULE, argc, argv,
 		GNOME_PARAM_POPT_TABLE, options,
 		GNOME_PROGRAM_STANDARD_PROPERTIES,
+	        GNOME_PARAM_APP_DATADIR, DATADIR"/gok", 
 		LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
 		NULL);
 
@@ -1637,6 +1638,7 @@ gok_main_set_wm_dock (gboolean is_dock)
   Atom atom_type[1], atom_window_type;
   GtkWidget *widget = gok_main_get_main_window ();
 
+  if (widget) gtk_widget_hide (widget);
   gdk_error_trap_push ();
   atom_window_type = gdk_x11_get_xatom_by_name ("_NET_WM_WINDOW_TYPE");
   if (is_dock) 
@@ -1650,6 +1652,7 @@ gok_main_set_wm_dock (gboolean is_dock)
 		   XA_ATOM, 32, PropModeReplace,
 		   (guchar *) &atom_type, 1);
   gdk_error_trap_pop ();
+  if (widget) gtk_widget_show (widget);
 
   if (m_pCurrentKeyboard) {
 	  gok_keyboard_display (m_pCurrentKeyboard, m_pCurrentKeyboard,
